@@ -127,7 +127,7 @@ sub _varchname {  # Copied from PPM.pm
   my ($self, $config) = @_;
   my $varchname = $config->{archname};
   # Append "-5.8" to architecture name for Perl 5.8 and later
-  if (length($^V) && ord(substr($^V,1)) >= 8) {
+  if (defined($^V) && ord(substr($^V,1)) >= 8) {
     $varchname .= sprintf("-%d.%d", ord($^V), ord(substr($^V,1)));
   }
   return $varchname;
@@ -151,25 +151,38 @@ sub _varchname {  # Copied from PPM.pm
 1;
 __END__
 
+
 =head1 NAME
 
 Module::Build::PPMMaker - Perl Package Manager file creation
 
+
 =head1 SYNOPSIS
 
- On the command line, builds a .ppd file:
- % ./Build ppd
+  On the command line, builds a .ppd file:
+  ./Build ppd
+
 
 =head1 DESCRIPTION
 
 This package contains the code that builds F<.ppd> "Perl Package
 Description" files, in support of ActiveState's "Perl Package
 Manager".  Details are here:
-L<"http://aspn.activestate.com/ASPN/Downloads/ActivePerl/PPM/">
+L<http://aspn.activestate.com/ASPN/Downloads/ActivePerl/PPM/>
+
 
 =head1 AUTHOR
 
-Dave Rolsky <autarch@urth.org>, Ken Williams <ken@mathforum.org>
+Dave Rolsky <autarch@urth.org>, Ken Williams <kwilliams@cpan.org>
+
+
+=head1 COPYRIGHT
+
+Copyright (c) 2001-2006 Ken Williams.  All rights reserved.
+
+This library is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
 
 =head1 SEE ALSO
 
