@@ -39,9 +39,9 @@ sub _myparse_from_filehandle {
   
   my @author;
   while (<$fh>) {
-    next unless /^=head1\s+AUTHOR/ ... /^=/;
+    next unless /^=head1\s+AUTHORS?/ ... /^=/;
     next if /^=/;
-    push @author, $_ if /\S/;
+    push @author, $_ if /\@/;
   }
   return unless @author;
   s/^\s+|\s+$//g foreach @author;
@@ -66,7 +66,7 @@ sub get_author {
   
   $self->parse_from_filehandle($self->{fh});
 
-  return $self->{author};  
+  return $self->{author} || [];
 }
 
 ################## Pod::Parser overrides ###########
@@ -85,7 +85,6 @@ sub command {
   }
 }
 
-
 sub textblock {
   my ($self, $text) = @_;
   $text =~ s/^\s+//;
@@ -93,8 +92,8 @@ sub textblock {
   if ($self->{_head} eq 'NAME') {
     my ($name, $abstract) = split( /\s+-\s+/, $text, 2 );
     $self->{abstract} = $abstract;
-  } elsif ($self->{_head} eq 'AUTHOR') {
-    push @{$self->{author}}, $text if $text =~ /\S/;
+  } elsif ($self->{_head} =~ /^AUTHORS?$/) {
+    push @{$self->{author}}, $text if $text =~ /\@/;
   }
 }
 
